@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -33,10 +33,12 @@ from holidays.holiday_base import HolidayBase
 
 
 class Afghanistan(HolidayBase, InternationalHolidays, IslamicHolidays, PersianCalendarHolidays):
-    """
-    https://en.wikipedia.org/wiki/Public_holidays_in_Afghanistan
-    https://www.timeanddate.com/holidays/afghanistan/
-    https://en.wikipedia.org/wiki/Workweek_and_weekend
+    """Afghanistan holidays.
+
+    References:
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Afghanistan>
+        * <https://www.timeanddate.com/holidays/afghanistan/>
+        * <https://en.wikipedia.org/wiki/Workweek_and_weekend>
     """
 
     country = "AF"
@@ -50,8 +52,10 @@ class Afghanistan(HolidayBase, InternationalHolidays, IslamicHolidays, PersianCa
 
     def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
         """
-        :param islamic_show_estimated:
-            Whether to add "estimated" label to Islamic holidays name if holiday date is estimated.
+        Args:
+            islamic_show_estimated:
+                Whether to add "estimated" label to Islamic holidays name
+                if holiday date is estimated.
         """
         InternationalHolidays.__init__(self)
         IslamicHolidays.__init__(
