@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -19,12 +19,11 @@ from holidays.holiday_base import HolidayBase
 
 
 class Bahrain(HolidayBase, InternationalHolidays, IslamicHolidays):
-    """
-    Bahrain holidays.
+    """Bahrain holidays.
 
     References:
-      - https://www.cbb.gov.bh/official-bank-holidays/
-      - https://www.officeholidays.com/countries/bahrain/
+        * <https://www.cbb.gov.bh/official-bank-holidays/>
+        * <https://www.officeholidays.com/countries/bahrain/>
     """
 
     country = "BH"
@@ -36,8 +35,10 @@ class Bahrain(HolidayBase, InternationalHolidays, IslamicHolidays):
 
     def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
         """
-        :param islamic_show_estimated:
-            Whether to add "estimated" label to Islamic holidays name if holiday date is estimated.
+        Args:
+            islamic_show_estimated:
+                Whether to add "estimated" label to Islamic holidays name
+                if holiday date is estimated.
         """
         InternationalHolidays.__init__(self)
         IslamicHolidays.__init__(
