@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -21,14 +21,16 @@ from holidays.observed_holiday_base import (
 
 
 class Barbados(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, StaticHolidays):
-    """
-    https://en.wikipedia.org/wiki/Public_holidays_in_Barbados
-    https://www.timeanddate.com/holidays/barbados/
-    [Public Holidays Act Cap.352] http://barbadosparliament-laws.com/en/showdoc/cs/352
-    https://labour.gov.bb/pdf/Library/Other%20Docs/Public%20Holidays%20for%20the%20Year%202018.pdf
-    https://labour.gov.bb/wp-content/uploads/2020/04/Public-Holidays-for-the-Year-2021.pdf
-    https://gisbarbados.gov.bb/download/public-holidays-for-2022/
-    https://gisbarbados.gov.bb/download/public-holidays-for-2023/
+    """Barbados holidays.
+
+    References:
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Barbados>
+        * <https://www.timeanddate.com/holidays/barbados/>
+        * [Public Holidays Act Cap.352](http://barbadosparliament-laws.com/en/showdoc/cs/352)
+        * <https://labour.gov.bb/pdf/Library/Other%20Docs/Public%20Holidays%20for%20the%20Year%202018.pdf>
+        * <https://labour.gov.bb/wp-content/uploads/2020/04/Public-Holidays-for-the-Year-2021.pdf>
+        * <https://gisbarbados.gov.bb/download/public-holidays-for-2022/>
+        * <https://gisbarbados.gov.bb/download/public-holidays-for-2023/>
     """
 
     country = "BB"
