@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -20,12 +20,13 @@ from holidays.observed_holiday_base import (
 
 
 class Belize(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
-    """
+    """Belize holidays.
+
     References:
-      - https://en.wikipedia.org/wiki/Public_holidays_in_Belize
-      - http://www.belizelaw.org/web/lawadmin/PDF%20files/cap289.pdf
-      - https://www.pressoffice.gov.bz/public-and-bank-holidays-2022-updated/
-      - https://www.pressoffice.gov.bz/government-of-belize-establishes-new-public-and-bank-holidays/
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Belize>
+        * <http://www.belizelaw.org/web/lawadmin/PDF%20files/cap289.pdf>
+        * <https://www.pressoffice.gov.bz/public-and-bank-holidays-2022-updated/>
+        * <https://www.pressoffice.gov.bz/government-of-belize-establishes-new-public-and-bank-holidays/>
     """
 
     country = "BZ"
