@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -22,17 +22,18 @@ from holidays.observed_holiday_base import (
 
 
 class Bolivia(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
-    """
+    """Bolivia holidays.
+
     References:
-    - [Supreme Decree #14260] https://bolivia.infoleyes.com/norma/1141/decreto-supremo-14260
-    - [Supreme Decree #21060] https://bolivia.infoleyes.com/norma/1211/decreto-supremo-21060
-    - [Supreme Decree #22352] https://bolivia.infoleyes.com/norma/1310/decreto-supremo-22352
-    - [Supreme Decree #0173] https://bolivia.infoleyes.com/norma/829/decreto-supremo-0173
-    - [Supreme Decree #0405] https://bolivia.infoleyes.com/norma/1252/decreto-supremo-0405
-    - [Supreme Decree #1210] https://bolivia.infoleyes.com/norma/3756/decreto-supremo-1210
-    - [Supreme Decree #2750] https://bolivia.infoleyes.com/norma/6023/decreto-supremo-2750
-    - https://en.wikipedia.org/wiki/Public_holidays_in_Bolivia
-    - https://www.officeholidays.com/countries/bolivia
+        * [Supreme Decree #14260](https://bolivia.infoleyes.com/norma/1141/decreto-supremo-14260)
+        * [Supreme Decree #21060](https://bolivia.infoleyes.com/norma/1211/decreto-supremo-21060)
+        * [Supreme Decree #22352](https://bolivia.infoleyes.com/norma/1310/decreto-supremo-22352)
+        * [Supreme Decree #0173](https://bolivia.infoleyes.com/norma/829/decreto-supremo-0173)
+        * [Supreme Decree #0405](https://bolivia.infoleyes.com/norma/1252/decreto-supremo-0405)
+        * [Supreme Decree #1210](https://bolivia.infoleyes.com/norma/3756/decreto-supremo-1210)
+        * [Supreme Decree #2750](https://bolivia.infoleyes.com/norma/6023/decreto-supremo-2750)
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Bolivia>
+        * <https://www.officeholidays.com/countries/bolivia>
     """
 
     country = "BO"
