@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -21,11 +21,13 @@ from holidays.observed_holiday_base import (
 
 
 class Botswana(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, StaticHolidays):
-    """
-    https://www.gov.bw/public-holidays
-    https://publicholidays.africa/botswana/2021-dates/
-    https://www.timeanddate.com/holidays/botswana/
-    http://www.ilo.org/dyn/travail/docs/1766/Public%20Holidays%20Act.pdf
+    """Botswana holidays.
+
+    References:
+        * <https://www.gov.bw/public-holidays>
+        * <https://publicholidays.africa/botswana/2021-dates/>
+        * <https://www.timeanddate.com/holidays/botswana/>
+        * <http://www.ilo.org/dyn/travail/docs/1766/Public%20Holidays%20Act.pdf>
     """
 
     country = "BW"
