@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -17,18 +17,35 @@ from holidays.observed_holiday_base import ObservedHolidayBase, SUN_TO_NEXT_MON
 
 
 class Cuba(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
-    """
-    Overview: https://en.wikipedia.org/wiki/Public_holidays_in_Cuba
-    1984 (DEC 28): https://bit.ly/3okNBbt
-    2007 (NOV 19): https://bit.ly/3oFbhaZ
-    2013 (DEC 20): https://bit.ly/3zoO3vC
-    Note: for holidays that can be moved to a Monday if they fall on a
-    Sunday, between 1984 and 2013, the State Committee of Work and
-    Social Security would determine if they would be moved to the
-    Monday, or if they would stay on the Sunday, presumably depending
-    on quotas. After 2013, they always move to Monday. I could not
-    find any records of this, so I implemented this making it always
-    go to the next Monday.
+    """Cuba holidays.
+
+    References:
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Cuba>
+        * [1984 (DEC 28)](https://files.sld.cu/prevemi/files/2013/03/ley_49_codigo_trabajo_1984.pdf)
+        * [2007 (NOV 19)](https://www.gacetaoficial.gob.cu/sites/default/files/go_x_053_2007.pdf)
+        * [2013 (DEC 20)](https://www.gacetaoficial.gob.cu/es/ley-no-116-codigo-de-trabajo)
+
+    Certain holidays details:
+        * Good Friday:
+            Granted temporarily in 2012 and 2013, permanently granted in 2013 decree for 2014
+            and onwards:
+                * <https://www.cnn.com/2012/03/31/world/americas/cuba-good-friday/index.html>
+                * <https://www.catholicnewsagency.com/news/29455/cuban-government-makes-good-friday-official-holiday>
+
+        * Christmas Day:
+            In 1969, Christmas was cancelled for the sugar harvest but then was cancelled for good:
+                * <https://time.com/vault/issue/1969-11-07/page/44/>
+            In 1997, Christmas was temporarily back for the Pope's visit:
+                * <http://www.cnn.com/WORLD/9712/15/castro.christmas/>
+            In 1998, Christmas returns for good:
+                * <https://www.independent.co.uk/news/cuba-ends-its-30year-ban-on-christmas-1193525.html>
+                * <https://www.ilo.org/dyn/travail/docs/1320/DECRETO-LEY%20No.%20189-1998.pdf>
+
+    For holidays that can be moved to a Monday if they fall on a Sunday, between 1984
+    and 2013, the State Committee of Work and Social Security would determine if they
+    would be moved to the Monday, or if they would stay on the Sunday, presumably
+    depending on quotas. After 2013, they always move to Monday. I could not find any
+    records of this, so I implemented this making it always go to the next Monday.
     """
 
     country = "CU"
@@ -51,15 +68,10 @@ class Cuba(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
         if self._year <= 2013:
             self._add_observed(jan_1)
 
-        # Granted in 2007 decree.
         if self._year >= 2008:
             #  Victory Day.
             self._add_holiday_jan_2(tr("Día de la Victoria"))
 
-        # Granted temporarily in 2012 and 2013:
-        #   https://cnn.it/3v5V6GY
-        #   https://bit.ly/3v6bM18
-        # Permanently granted in 2013 decree for 2014 and onwards.
         if self._year >= 2012:
             # Good Friday.
             self._add_good_friday(tr("Viernes Santo"))
@@ -79,19 +91,10 @@ class Cuba(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
         # Independence Day.
         self._add_observed(self._add_holiday_oct_10(tr("Inicio de las Guerras de Independencia")))
 
-        # In 1969, Christmas was cancelled for the sugar harvest but then was
-        # cancelled for good:
-        #   https://bit.ly/3OpwX5i
-        # In 1997, Christmas was temporarily back for the pope's visit:
-        #   https://cnn.it/3Omn349
-        # In 1998, Christmas returns for good:
-        #   https://bit.ly/3cyXhwz
-        #   https://bit.ly/3cyXj7F
         if self._year <= 1968 or self._year >= 1997:
             # Christmas Day.
             self._add_christmas_day(tr("Día de Navidad"))
 
-        # Granted in 2007 decree.
         if self._year >= 2007:
             # New Year's Eve.
             self._add_new_years_eve(tr("Fiesta de Fin de Año"))
