@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -20,9 +20,11 @@ from holidays.holiday_base import HolidayBase
 
 
 class Curacao(HolidayBase, ChristianHolidays, InternationalHolidays):
-    """
-    https://loketdigital.gobiernu.cw/Loket/product/571960bbe1e5fe8712b10a1323630e70
-    https://en.wikipedia.org/wiki/Public_holidays_in_Cura%C3%A7ao
+    """Curaçao holidays.
+
+    References:
+        * <https://loketdigital.gobiernu.cw/Loket/product/571960bbe1e5fe8712b10a1323630e70>
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Cura%C3%A7ao>
     """
 
     country = "CW"
