@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -20,12 +20,11 @@ from holidays.holiday_base import HolidayBase
 
 
 class Georgia(HolidayBase, ChristianHolidays, InternationalHolidays):
-    """
-    Georgia holidays.
+    """Georgia holidays.
 
     References:
-     - https://en.wikipedia.org/wiki/Public_holidays_in_Georgia_(country)
-     - https://matsne.gov.ge/en/document/view/1155567?publication=24
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Georgia_(country)>
+        * <https://matsne.gov.ge/en/document/view/1155567?publication=24>
     """
 
     country = "GE"
@@ -101,9 +100,10 @@ class GEO(Georgia):
 
 
 class GeorgiaStaticHolidays:
-    """
+    """Georgia special holidays.
+
     References:
-        - https://www.matsne.gov.ge/ka/document/view/6173967
+        * <https://www.matsne.gov.ge/ka/document/view/6173967>
     """
 
     special_government_holidays = {
