@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -19,15 +19,14 @@ from holidays.holiday_base import HolidayBase
 
 
 class Germany(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolidays):
-    """Official holidays for Germany in its current form.
+    """Germany holidays.
 
     This class doesn't return any holidays before 1990-10-03.
 
-    Before that date the current Germany was separated into the "German
-    Democratic Republic" and the "Federal Republic of Germany" which both had
-    somewhat different holidays. Since this class is called "Germany" it
-    doesn't really make sense to include the days from the two former
-    countries.
+    Before that date the current Germany was separated into the "German Democratic
+    Republic" and the "Federal Republic of Germany" which both had somewhat
+    different holidays. Since this class is called "Germany" it doesn't really
+     make sense to include the days from the two former countries.
 
     "Mariä Himmelfahrt" is only a holiday in Bavaria (BY) and "Fronleichnam"
     in Saxony (SN) and Thuringia (TH) if municipality is mostly catholic which
@@ -241,11 +240,12 @@ class DEU(Germany):
 
 
 class GermanyStaticHolidays:
-    """
+    """Germany special holidays.
+
     References:
-     - https://www.stuttgarter-zeitung.de/inhalt.reformationstag-2017-einmalig-bundesweiter-feiertag.b7e189b3-a33d-41a3-a0f4-141cd13df54e.html
-     - https://www.bbc.com/news/world-europe-52574748
-     - https://gesetze.berlin.de/bsbe/document/jlr-FeiertGBEV8P1
+        * <https://www.stuttgarter-zeitung.de/inhalt.reformationstag-2017-einmalig-bundesweiter-feiertag.b7e189b3-a33d-41a3-a0f4-141cd13df54e.html>
+        * <https://www.bbc.com/news/world-europe-52574748>
+        * <https://gesetze.berlin.de/bsbe/document/jlr-FeiertGBEV8P1>
     """
 
     special_public_holidays = {
