@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -16,10 +16,11 @@ from holidays.holiday_base import HolidayBase
 
 
 class Ireland(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolidays):
-    """
+    """Ireland holidays.
+
     References:
-        - https://en.wikipedia.org/wiki/Public_holidays_in_the_Republic_of_Ireland
-        - https://www.citizensinformation.ie/en/employment/employment_rights_and_conditions/leave_and_holidays/public_holidays_in_ireland.html
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_the_Republic_of_Ireland>
+        * <https://www.citizensinformation.ie/en/employment/employment_rights_and_conditions/leave_and_holidays/public_holidays_in_ireland.html>
     """
 
     country = "IE"
