@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -16,10 +16,11 @@ from holidays.holiday_base import HolidayBase
 
 
 class Italy(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolidays):
-    """
+    """Italy holidays.
+
     References:
-        - https://en.wikipedia.org/wiki/Public_holidays_in_Italy
-        - `Provinces holidays <https://it.wikipedia.org/wiki/Santi_patroni_cattolici_delle_citt%C3%A0_capoluogo_di_provincia_italiane>`_
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Italy>
+        * [Provinces holidays](https://it.wikipedia.org/wiki/Santi_patroni_cattolici_delle_citt%C3%A0_capoluogo_di_provincia_italiane)
     """
 
     country = "IT"
