@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -18,10 +18,11 @@ from holidays.holiday_base import HolidayBase
 
 
 class Jordan(HolidayBase, ChristianHolidays, InternationalHolidays, IslamicHolidays):
-    """
+    """Jordan holidays.
+
     References:
-        - https://en.wikipedia.org/wiki/Public_holidays_in_Jordan
-        - https://www.mfa.gov.jo/content/public-holidays
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Jordan>
+        * <https://www.mfa.gov.jo/content/public-holidays>
     """
 
     country = "JO"
@@ -32,8 +33,10 @@ class Jordan(HolidayBase, ChristianHolidays, InternationalHolidays, IslamicHolid
 
     def __init__(self, islamic_show_estimated: bool = True, *args, **kwargs):
         """
-        :param islamic_show_estimated:
-            Whether to add "estimated" label to Islamic holidays name if holiday date is estimated.
+        Args:
+            islamic_show_estimated:
+                Whether to add "estimated" label to Islamic holidays name
+                if holiday date is estimated.
         """
         ChristianHolidays.__init__(self)
         InternationalHolidays.__init__(self)
