@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -18,11 +18,11 @@ from holidays.holiday_base import HolidayBase
 
 
 class Liechtenstein(HolidayBase, ChristianHolidays, InternationalHolidays):
-    """
-    Liechtenstein holidays.
+    """Liechtenstein holidays.
+
     References:
-    - https://en.wikipedia.org/wiki/Public_holidays_in_Liechtenstein
-    - https://www.llb.li/en/contact/bank-holidays
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Liechtenstein>
+        * <https://www.llb.li/en/contact/bank-holidays>
     """
 
     country = "LI"
