@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -18,10 +18,11 @@ from holidays.holiday_base import HolidayBase
 
 
 class Madagascar(HolidayBase, ChristianHolidays, InternationalHolidays):
-    """
+    """Madagascar holidays.
+
     References:
-        - https://www.officeholidays.com/countries/madagascar
-        - https://www.timeanddate.com/holidays/madagascar/
+        * <https://www.officeholidays.com/countries/madagascar>
+        * <https://www.timeanddate.com/holidays/madagascar/>
     """
 
     country = "MG"
