@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -19,9 +19,11 @@ from holidays.observed_holiday_base import (
 
 
 class Malawi(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
-    """
-    https://www.officeholidays.com/countries/malawi
-    https://www.timeanddate.com/holidays/malawi/
+    """Malawi holidays.
+
+    References:
+        * <https://www.officeholidays.com/countries/malawi>
+        * <https://www.timeanddate.com/holidays/malawi/>
     """
 
     country = "MW"
