@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -15,9 +15,11 @@ from holidays.countries.united_states import US
 
 
 class HolidaysMP(US):
-    # Alias of a US subdivision that is also officially assigned its own
-    # country code in ISO 3166-1.  See
-    # https://en.wikipedia.org/wiki/ISO_3166-2:US#Subdivisions_included_in_ISO_3166-1
+    """Northern Mariana Islands (the) holidays.
+
+    Alias of a US subdivision that is also officially assigned its own country code in ISO 3166-1.
+    See <https://en.wikipedia.org/wiki/ISO_3166-2:US#Subdivisions_included_in_ISO_3166-1>
+    """
 
     country = "MP"
     supported_categories = (GOVERNMENT, PUBLIC, UNOFFICIAL)
