@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -18,11 +18,12 @@ from holidays.holiday_base import HolidayBase
 
 
 class Poland(HolidayBase, ChristianHolidays, InternationalHolidays, StaticHolidays):
-    """
+    """Poland holidays.
+
     References:
-        - https://en.wikipedia.org/wiki/Public_holidays_in_Poland
-        - https://pl.wikipedia.org/wiki/Dni_wolne_od_pracy_w_Polsce
-        - https://isap.sejm.gov.pl/isap.nsf/DocDetails.xsp?id=WDU20240001965
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Poland>
+        * <https://pl.wikipedia.org/wiki/Dni_wolne_od_pracy_w_Polsce>
+        * <https://isap.sejm.gov.pl/isap.nsf/DocDetails.xsp?id=WDU20240001965>
     """
 
     country = "PL"
