@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -18,9 +18,11 @@ from holidays.holiday_base import HolidayBase
 
 
 class Romania(HolidayBase, ChristianHolidays, InternationalHolidays):
-    """
-    https://en.wikipedia.org/wiki/Public_holidays_in_Romania
-    http://www.dreptonline.ro/legislatie/codul_muncii.php
+    """Romania holidays.
+
+    References:
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Romania>
+        * <http://www.dreptonline.ro/legislatie/codul_muncii.php>
     """
 
     country = "RO"
