@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -51,39 +51,31 @@ class SouthKorea(
     InternationalHolidays,
     StaticHolidays,
 ):
-    """
+    """South Korea holidays.
+
     References:
-        - https://en.wikipedia.org/wiki/Public_holidays_in_South_Korea
-        - https://www.law.go.kr/법령/관공서의%20공휴일에%20관한%20규정
-        - https://elaw.klri.re.kr/eng_service/lawView.do?lang=ENG&hseq=34678
-        - https://elaw.klri.re.kr/eng_service/%20lawView.do?hseq=38405&lang=ENG
-        - https://namu.wiki/w/대통령%20선거일
-        - https://namu.wiki/w/공휴일/대한민국
-        - https://namu.wiki/w/공휴일/대한민국/역사
-        - https://namu.wiki/w/대체%20휴일%20제도
-        - `TH localization 1 <https://overseas.mofa.go.kr/th-th/wpge/m_3133/contents.do>`_
-        - `TH localization 2 <https://thailand.korean-culture.org/th/138/korea/38>`_
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_South_Korea>
+        * <https://www.law.go.kr/법령/관공서의%20공휴일에%20관한%20규정>
+        * <https://elaw.klri.re.kr/eng_service/lawView.do?lang=ENG&hseq=34678>
+        * <https://elaw.klri.re.kr/eng_service/%20lawView.do?hseq=38405&lang=ENG>
+        * <https://namu.wiki/w/대통령%20선거일>
+        * <https://namu.wiki/w/공휴일/대한민국>
+        * <https://namu.wiki/w/공휴일/대한민국/역사>
+        * <https://namu.wiki/w/대체%20휴일%20제도>
+        * [TH localization 1](https://overseas.mofa.go.kr/th-th/wpge/m_3133/contents.do)
+        * [TH localization 2](https://thailand.korean-culture.org/th/138/korea/38)
 
     Checked With:
-        - https://publicholidays.co.kr/ko/2020-dates/
-        - https://publicholidays.co.kr/ko/2022-dates/
+        * <https://publicholidays.co.kr/ko/2020-dates/>
+        * <https://publicholidays.co.kr/ko/2022-dates/>
 
     According to (3), the alt holidays in Korea are as follows:
-        - The alt holiday means next first non holiday after the holiday.
-        - Independence Movement Day, Liberation Day, National Foundation Day,
+        * The alt holiday means next first non holiday after the holiday.
+        * Independence Movement Day, Liberation Day, National Foundation Day,
             Hangul Day, Children's Day, Birthday of the Buddha, Christmas Day have
             alt holiday if they fell on Saturday or Sunday.
-        - Korean New Year's Day, Korean Mid Autumn Day have alt holiday if they
+        * Korean New Year's Day, Korean Mid Autumn Day have alt holiday if they
             fell on Sunday.
-
-    The alt holidays in Korea are as follows:
-        - The alt holiday means next first non holiday after the holiday.
-        - Independence Movement Day, Liberation Day, National Foundation Day,
-            Hangul Day, Children's Day, Birthday of the Buddha, Christmas Day have
-            alt holiday if they fell on Saturday or Sunday.
-        - Lunar New Year's Day, Korean Mid Autumn Day have alt holiday if they
-            fell on Sunday.
-
     """
 
     country = "KR"
@@ -221,7 +213,7 @@ class SouthKorea(
         # Christmas Day.
         append_observed(self._add_christmas_day(tr("기독탄신일")), 2023)
 
-        # Election Days since Sep 2006; excluding the 2017 Special Presidential Election Day.
+        # Election Days since Sep 2006; excluding the 2017, 2025 Special Presidential Election Day.
 
         # Based on Article 34 of the Public Official Election Act.
         # (1) The election day for each election to be held at the expiration of the term shall
@@ -246,23 +238,18 @@ class SouthKorea(
         elif self._year >= 2007 and (self._year - 2008) % 4 == 0:
             self._add_holiday_2nd_wed_of_apr(name)
 
-        if self._year >= 2007 and (self._year - 2007) % 5 == 0:
+        if self._year >= 2007:
             # Presidential Election Day.
             name = tr("대통령 선거일")
-
-            if self._year <= 2012:
-                self._add_holiday_3rd_wed_of_dec(name)
-            elif self._year >= 2022:
-                if (
-                    self._is_tuesday(mar_1)
-                    or self._is_wednesday(mar_1)
-                    or self._is_thursday(mar_1)
-                ):
+            if self._year <= 2024 and (self._year - 2007) % 5 == 0:
+                if self._year <= 2012:
+                    self._add_holiday_3rd_wed_of_dec(name)
+                elif self._year >= 2022:
                     # Moved as per Paragraph 2 of Article 34 due to conflict with
                     # Independence Movement Day (MAR, 1).
                     self._add_holiday_2nd_wed_of_mar(name)
-                else:
-                    self._add_holiday_1st_wed_of_mar(name)
+            elif self._year >= 2030 and (self._year - 2030) % 5 == 0:
+                self._add_holiday_1st_wed_of_apr(name)
 
         if self._year >= 2007 and (self._year - 2010) % 4 == 0:
             # Local Election Day.
@@ -331,15 +318,16 @@ class SouthKoreaLunisolarHolidays(_CustomChineseHolidays):
 
 
 class SouthKoreaStaticHolidays:
-    """
-    References:
-        - https://namu.wiki/w/임시공휴일 *
-        - https://namu.wiki/w/공휴일/대한민국 **
-        - https://namu.wiki/w/대체%20휴일%20제도
+    """South Korea special holidays.
 
-    (1) Election Dates featured here are the ones prior to the proper recodification to
+    References:
+        * <https://namu.wiki/w/임시공휴일> *
+        * <https://namu.wiki/w/공휴일/대한민국> **
+        * <https://namu.wiki/w/대체%20휴일%20제도>
+
+    1. Election Dates featured here are the ones prior to the proper recodification to
         Article 34 of the Public Official Election Act(September 2006)
-    (2) Sabang Day (사방의 날) was technically in the Public Holidays Act itself, but since it was
+    2. Sabang Day (사방의 날) was technically in the Public Holidays Act itself, but since it was
         only celebrated in 1960, this is being put here.
     """
 
@@ -617,8 +605,12 @@ class SouthKoreaStaticHolidays:
         2023: (OCT, 2, temporary_public_holiday),
         # 76th Anniversary of the Armed Forces of Korea.
         2024: (OCT, 1, armed_forces_day),
-        # Added to create a 6-day long holiday period.
-        2025: (JAN, 27, temporary_public_holiday),
+        2025: (
+            # Added to create a 6-day long holiday period.
+            (JAN, 27, temporary_public_holiday),
+            # Special Presidential Election (21st) due to Yoon Seok-yeol's impeachment.
+            (JUN, 3, presidential_election_day),
+        ),
     }
     # Pre-2014 Alternate Holidays
     # https://namu.wiki/w/대체%20휴일%20제도#s-4.2.1
