@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -32,60 +32,55 @@ GA_IN_WASHINGTON_BIRTHDAY = ObservedRule(
 
 
 class UnitedStates(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
-    """
-    https://en.wikipedia.org/wiki/Public_holidays_in_the_United_States
+    """United States of America (the) holidays.
 
-    Federal holidays:
-        - https://www.opm.gov/policy-data-oversight/pay-leave/federal-holidays/
-
-    For Northern Mariana Islands (subdivision MP):
-    - https://governor.gov.mp/archived-news/executive-actions-archive/memorandum-2022-legal-holidays/
-    - https://webcache.googleusercontent.com/search?q=cache:C17_7FBgPtQJ:https://governor.gov.mp/archived-news/executive-actions-archive/memorandum-2022-legal-holidays/&hl=en&gl=sg&strip=1&vwsrc=0
-
-    Columbus Day / Indigenous Peoples' Day history:
-    - https://www.pewresearch.org/short-reads/2023/10/05/working-on-columbus-day-or-indigenous-peoples-day-it-depends-on-where-your-job-is/
-    - https://www.officeholidays.com/holidays/usa/columbus-day-state-guide
-    - https://en.wikipedia.org/wiki/Indigenous_Peoples%27_Day_(United_States)
-    - https://www.sos.ri.gov/divisions/civics-and-education/reference-desk/ri-state-holidays
-    - https://web.archive.org/web/20080831103521/http://www.dpa.ca.gov/personnel-policies/holidays.htm
-
-    Frances Xavier Cabrini Day:
-        - https://leg.colorado.gov/sites/default/files/2020a_1031_signed.pdf
-
-    Washington's Birthday:
-        - AK: https://doa.alaska.gov/calendar/
-        - AL: https://admincode.legislature.state.al.us/administrative-code/670-X-12-.01
-        - AR: https://arkleg.state.ar.us/Home/FTPDocument?path=/ACTS/2001/Public/ACT304.pdf
-        - AZ: https://www.azleg.gov/ars/1/00301.htm
-        - CA: https://www.sos.ca.gov/state-holidays
-        - CO: https://leg.colorado.gov/sites/default/files/images/olls/crs2023-title-24.pdf
-        - GA: https://www.gasupreme.us/court-information/holidays-2/
-        - HI: https://www.capitol.hawaii.gov/hrscurrent/Vol01_Ch0001-0042F/HRS0008/HRS_0008-0001.htm
-        - ID: https://idaho.gov/government/state-holidays/
-        - IN: https://digital.statelib.lib.in.us/infoexpress/holidays.aspx
-              https://www.in.gov/spd/benefits/state-holidays/
-        - MD: https://msa.maryland.gov/msa/mdmanual/01glance/html/holidayl.html
-        - MI: https://www.michigan.gov/som/government/state-holidays
-        - MN: https://www.revisor.mn.gov/statutes/cite/645.44
-        - MT: https://archive.legmt.gov/bills/mca/title_0010/chapter_0010/part_0020/section_0160/0010-0010-0020-0160.html
-        - NJ: https://nj.gov/nj/about/facts/holidays/
-        - OH: https://codes.ohio.gov/ohio-revised-code/section-1.14
-        - OK: https://oklahoma.gov/omes/divisions/human-capital-management/employee-benefits/leave-holidays/holidays.html
-        - OR: https://www.oregonlegislature.gov/bills_laws/ors/ors187.html
-        - PA: https://www.legis.state.pa.us/WU01/LI/LI/US/PDF/1893/0/0138..PDF
-        - PR: https://en.wikipedia.org/wiki/Public_holidays_in_Puerto_Rico
-        - SC: https://www.scstatehouse.gov/code/t53c005.php
-        - TN: https://www.tn.gov/about-tn/state-holidays.html
-        - TX: https://www.tsl.texas.gov/ref/abouttx/holidays
-        - UT: https://le.utah.gov/xcode/Title63G/Chapter1/63G-1-S301.html
-        - VA: https://law.lis.virginia.gov/vacode/title2.2/chapter33/section2.2-3300/
-        - VT: https://legislature.vermont.gov/statutes/section/01/007/00371
-        - WA: https://app.leg.wa.gov/rcw/default.aspx?cite=1.16.050
-        - WV: https://code.wvlegislature.gov/2-2-1/
-        - WY: https://ai.wyo.gov/about-us/state-holidays-and-office-closures
-
-    American Samoa holidays:
-        - https://asbar.org/code-annotated/1-0501-public-holidays/
+    References:
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_the_United_States>
+        * [Federal holidays](https://www.opm.gov/policy-data-oversight/pay-leave/federal-holidays/)
+        * Washington's Birthday:
+            * [AK](https://doa.alaska.gov/calendar/)
+            * [AL](https://admincode.legislature.state.al.us/administrative-code/670-X-12-.01)
+            * [AR](https://arkleg.state.ar.us/Home/FTPDocument?path=/ACTS/2001/Public/ACT304.pdf)
+            * [AZ](https://www.azleg.gov/ars/1/00301.htm)
+            * [CA](https://www.sos.ca.gov/state-holidays)
+            * [CO](https://leg.colorado.gov/sites/default/files/images/olls/crs2023-title-24.pdf)
+            * [GA](https://www.gasupreme.us/court-information/holidays-2/)
+            * [HI](https://www.capitol.hawaii.gov/hrscurrent/Vol01_Ch0001-0042F/HRS0008/HRS_0008-0001.htm)
+            * [ID](https://idaho.gov/government/state-holidays/)
+            * IN:
+                * <https://digital.statelib.lib.in.us/infoexpress/holidays.aspx>
+                * <https://www.in.gov/spd/benefits/state-holidays/>
+            * [MD](https://msa.maryland.gov/msa/mdmanual/01glance/html/holidayl.html)
+            * [MI](https://www.michigan.gov/som/government/state-holidays)
+            * [MN](https://www.revisor.mn.gov/statutes/cite/645.44)
+            * [MT](https://archive.legmt.gov/bills/mca/title_0010/chapter_0010/part_0020/section_0160/0010-0010-0020-0160.html)
+            * [NJ](https://nj.gov/nj/about/facts/holidays/)
+            * [OH](https://codes.ohio.gov/ohio-revised-code/section-1.14)
+            * [OK](https://oklahoma.gov/omes/divisions/human-capital-management/employee-benefits/leave-holidays/holidays.html)
+            * [OR](https://www.oregonlegislature.gov/bills_laws/ors/ors187.html)
+            * [PA](https://www.legis.state.pa.us/WU01/LI/LI/US/PDF/1893/0/0138..PDF)
+            * [PR](https://en.wikipedia.org/wiki/Public_holidays_in_Puerto_Rico)
+            * [SC](https://www.scstatehouse.gov/code/t53c005.php)
+            * [TN](https://www.tn.gov/about-tn/state-holidays.html)
+            * [TX](https://www.tsl.texas.gov/ref/abouttx/holidays)
+            * [UT](https://le.utah.gov/xcode/Title63G/Chapter1/63G-1-S301.html)
+            * [VA](https://law.lis.virginia.gov/vacode/title2.2/chapter33/section2.2-3300/)
+            * [VT](https://legislature.vermont.gov/statutes/section/01/007/00371)
+            * [WA](https://app.leg.wa.gov/rcw/default.aspx?cite=1.16.050)
+            * [WV](https://code.wvlegislature.gov/2-2-1/)
+            * [WY](https://ai.wyo.gov/about-us/state-holidays-and-office-closures)
+        * Columbus Day / Indigenous Peoples' Day history:
+            * <https://www.pewresearch.org/short-reads/2023/10/05/working-on-columbus-day-or-indigenous-peoples-day-it-depends-on-where-your-job-is/>
+            * <https://www.officeholidays.com/holidays/usa/columbus-day-state-guide>
+            * <https://en.wikipedia.org/wiki/Indigenous_Peoples%27_Day_(United_States)>
+            * <https://www.sos.ri.gov/divisions/civics-and-education/reference-desk/ri-state-holidays>
+            * <https://web.archive.org/web/20080831103521/http://www.dpa.ca.gov/personnel-policies/holidays.htm>
+        * [Frances Xavier Cabrini Day](https://leg.colorado.gov/sites/default/files/2020a_1031_signed.pdf)
+        * Northern Mariana Islands (subdivision MP):
+            * <https://governor.gov.mp/archived-news/executive-actions-archive/memorandum-2022-legal-holidays/>
+            * <https://webcache.googleusercontent.com/search?q=cache:C17_7FBgPtQJ:https://governor.gov.mp/archived-news/executive-actions-archive/memorandum-2022-legal-holidays/&hl=en&gl=sg&strip=1&vwsrc=0>
+        * American Samoa:
+            * <https://asbar.org/code-annotated/1-0501-public-holidays/>
     """
 
     country = "US"
