@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -16,10 +16,12 @@ from holidays.observed_holiday_base import ObservedHolidayBase, SUN_TO_NEXT_MON,
 
 
 class Vanuatu(ObservedHolidayBase, ChristianHolidays, InternationalHolidays, StaticHolidays):
-    """
-    https://en.wikipedia.org/wiki/Public_holidays_in_Vanuatu
-    https://www.timeanddate.com/holidays/vanuatu/
-    https://www.gov.vu/index.php/events/holidays
+    """Vanuatu holidays.
+
+    References:
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Vanuatu>
+        * <https://www.timeanddate.com/holidays/vanuatu/>
+        * <https://www.gov.vu/index.php/events/holidays>
     """
 
     country = "VU"
