@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -15,9 +15,11 @@ from holidays.observed_holiday_base import ObservedHolidayBase, SUN_TO_NEXT_MON,
 
 
 class Zimbabwe(ObservedHolidayBase, ChristianHolidays, InternationalHolidays):
-    """
-    https://en.wikipedia.org/wiki/Public_holidays_in_Zimbabwe
-    https://en.wikipedia.org/wiki/Robert_Gabriel_Mugabe_National_Youth_Day
+    """Zimbabwe holidays.
+
+    References:
+        * <https://en.wikipedia.org/wiki/Public_holidays_in_Zimbabwe>
+        * <https://en.wikipedia.org/wiki/Robert_Gabriel_Mugabe_National_Youth_Day>
     """
 
     country = "ZW"
