@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -34,13 +34,15 @@ from holidays.observed_holiday_base import ObservedHolidayBase, SAT_TO_PREV_FRI,
 class NewYorkStockExchange(
     ObservedHolidayBase, ChristianHolidays, InternationalHolidays, StaticHolidays
 ):
-    """
-    Official regulations:
-    - https://www.nyse.com/publicdocs/nyse/regulation/nyse/NYSE_Rules.pdf
-    - https://www.nyse.com/markets/hours-calendars
+    """New York Stock Exchange holidays.
+
+    References:
+        * <https://www.nyse.com/publicdocs/nyse/regulation/nyse/NYSE_Rules.pdf>
+        * <https://www.nyse.com/markets/hours-calendars>
+
     Historical data:
-    - s3.amazonaws.com/armstrongeconomics-wp/2013/07/NYSE-Closings.pdf
-    - https://web.archive.org/web/20211101162021/https://www.nyse.com/markets/hours-calendars
+        * <https://s3.amazonaws.com/armstrongeconomics-wp/2013/07/NYSE-Closings.pdf>
+        * <https://web.archive.org/web/20211101162021/https://www.nyse.com/markets/hours-calendars>
     """
 
     market = "XNYS"
@@ -147,10 +149,11 @@ class NYSE(NewYorkStockExchange):
 
 
 class NewYorkStockExchangeStaticHolidays:
-    """
+    """New York Stock Exchange special holidays.
+
     References:
-    - https://guides.loc.gov/presidents-portraits/chronological
-    - https://www.presidency.ucsb.edu/documents/proclamation-3561-national-day-mourning-for-president-kennedy
+        * <https://guides.loc.gov/presidents-portraits/chronological>
+        * <https://www.presidency.ucsb.edu/documents/proclamation-3561-national-day-mourning-for-president-kennedy>
     """
 
     # Blizzard of 1888.
