@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -14,7 +14,7 @@
 class PreferredDiscretionaryHolidays:
     """A mixin for setting preferred discretionary holidays.
 
-    See :class:`holidays.countries.hongkong.HongKong` for an example.
+    See [HongKong][holidays.countries.hongkong.HongKong] for an example.
     """
 
     default_preferred_discretionary_holidays: tuple[str, ...] = ()
