@@ -1,12 +1,13 @@
 #!/usr/bin/env python3
 
+
 #  holidays
 #  --------
 #  A fast, efficient Python library for generating country, province and state
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -17,9 +18,11 @@ import inspect
 import sys
 from pathlib import Path
 
-from lingva.extract import main as create_pot_file
+from lingva.extract import extract as create_pot_file
 from polib import pofile
 
+WRAP_WIDTH = 99
+
 
 class POGenerator:
     """Generates .po files for supported country/market entities."""
@@ -27,7 +30,7 @@ class POGenerator:
     @staticmethod
     def update_po_file(po_path: str, pot_path: str, package_version: str) -> None:
         """Merge .po file with .pot"""
-        po_file = pofile(po_path)
+        po_file = pofile(po_path, wrapwidth=WRAP_WIDTH)
         po_file_initial = po_file.copy()
         pot_file = pofile(pot_path)
 
@@ -70,41 +73,33 @@ class POGenerator:
             pot_file_path = pot_path / f"{entity_code}.pot"
             # Create .pot file.
             create_pot_file(
-                (
-                    f"{class_file_path}",
-                    "-k",
-                    "tr",
-                    "-o",
-                    f"{pot_file_path}",
-                    "--package-name",
-                    "Holidays",
-                    "--package-version",
-                    package_version,
-                    "--width",
-                    "100",
-                    "--no-location",
-                ),
-                standalone_mode=False,
+                sources=[class_file_path],
+                keywords=["tr"],
+                output=pot_file_path,
+                package_name="Holidays",
+                package_version=package_version,
+                width=WRAP_WIDTH,
+                location=False,
+                allow_empty=True,
             )
 
             # Update .pot file metadata.
-            pot_file = pofile(pot_file_path)
+            pot_file = pofile(pot_file_path, wrapwidth=WRAP_WIDTH)
             pot_file.metadata.update(
                 {
                     "Language": default_language,
                     "Language-Team": "Holidays Localization Team",
-                    "PO-Revision-Date": pot_file.metadata["POT-Creation-Date"],
                     "X-Source-Language": default_language,
                 }
             )
-            pot_file.save()
+            pot_file.save(newline="\n")
 
             # Create entity default .po file from the .pot file.
             po_directory = locale_path / default_language / "LC_MESSAGES"
             po_directory.mkdir(parents=True, exist_ok=True)
             po_file_path = po_directory / f"{entity_code}.po"
             if not po_file_path.exists():
-                pofile(pot_file_path).save(po_file_path)
+                pot_file.save(po_file_path, newline="\n")
 
             # Update all .po files.
             for po_file_path in locale_path.rglob(f"{entity_code}.po"):
