@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -569,20 +569,20 @@ class TestIndia(CommonCountryTests, TestCase):
             ("2018-01-14", "उत्तरायण; पोंगल; मकर संक्रांति; माघ बिहू"),
             ("2018-01-24", "यूपी स्थापना दिवस"),
             ("2018-01-26", "गणतंत्र दिवस"),
-            ("2018-02-13", "महा शिवरात्रि"),
+            ("2018-02-13", "महाशिवरात्रि"),
             ("2018-02-19", "छत्रपति शिवाजी महाराज जयंती"),
             ("2018-02-20", "मिज़ोरम राज्य दिवस"),
             ("2018-03-02", "होली"),
             ("2018-03-18", "गुडी पाडवा"),
             ("2018-03-22", "बिहार दिवस"),
-            ("2018-03-25", "पाम संडे; राम नवमी"),
+            ("2018-03-25", "पाम संडे; रामनवमी"),
             ("2018-03-29", "महावीर जयंती"),
             ("2018-03-30", "गुड फ्राइडे; राजस्थान दिवस"),
             ("2018-04-01", "ईस्टर संडे; ओडिशा दिवस (उत्कल दिवस)"),
-            ("2018-04-14", "डॉ. बी.आर. अम्बेडकर जयंती; पुथंडु (तमिल नव वर्ष); वैसाखी"),
-            ("2018-04-15", "पोहेला बोइशाख; महा विशुव संक्रांति / पण संक्रांति; हिमाचल दिवस"),
+            ("2018-04-14", "डॉ. बी.आर. आम्बेडकर जयंती; पुत्ताण्डु (तमिल नव वर्ष); वैसाखी"),
+            ("2018-04-15", "पोहेला बोइशाख; महा विषुव संक्रांति / पण संक्रांति; हिमाचल दिवस"),
             ("2018-04-30", "बुद्ध पूर्णिमा"),
-            ("2018-05-01", "गुजरात दिवस; महाराष्ट्र दिवस; श्रमिक दिवस"),
+            ("2018-05-01", "गुजरात दिवस; मजदूर दिवस; महाराष्ट्र दिवस"),
             ("2018-05-09", "रवींद्र जयंती"),
             ("2018-05-16", "सिक्किम राज्य दिवस"),
             ("2018-06-02", "तेलंगाना स्थापना दिवस"),
@@ -599,7 +599,7 @@ class TestIndia(CommonCountryTests, TestCase):
             ("2018-10-02", "गांधी जयंती"),
             ("2018-10-06", "बतुकम्मा महोत्सव"),
             ("2018-10-10", "नवरात्र/शरद नवरात्र"),
-            ("2018-10-18", "महा नवमी"),
+            ("2018-10-18", "महानवमी"),
             ("2018-10-19", "दशहरा"),
             ("2018-10-31", "सरदार वल्लभभाई पटेल जयंती"),
             (
@@ -614,7 +614,7 @@ class TestIndia(CommonCountryTests, TestCase):
             ("2018-11-08", "गोवर्धन पूजा"),
             ("2018-11-13", "छठ पूजा"),
             ("2018-11-14", "बाल दिवस"),
-            ("2018-11-15", "झारखण्ड स्थापना दिवस"),
+            ("2018-11-15", "झारखंड स्थापना दिवस"),
             ("2018-11-21", "मिलाद-उन-नबी"),
             ("2018-11-23", "गुरु नानक जयंती"),
             ("2018-12-01", "नागालैंड राज्य उद्घाटन दिवस"),
