@@ -4,7 +4,7 @@
 #  specific sets of holidays on the fly. It aims to make determining whether a
 #  specific date is a holiday as fast and flexible as possible.
 #
-#  Authors: Vacanza Team and individual contributors (see AUTHORS file)
+#  Authors: Vacanza Team and individual contributors (see AUTHORS.md file)
 #           dr-prodigy <dr.prodigy.github@gmail.com> (c) 2017-2023
 #           ryanss <ryanssdev@icloud.com> (c) 2014-2017
 #  Website: https://github.com/vacanza/holidays
@@ -238,10 +238,14 @@ class TestPhilippines(CommonCountryTests, TestCase):
         name = "Bonifacio Day"
         self.assertHolidayName(
             name,
-            (f"{year}-11-30" for year in (*range(1988, 2008), *range(2011, 2050))),
+            (
+                f"{year}-11-30"
+                for year in (*range(1988, 2008), *range(2011, 2023), *range(2024, 2050))
+            ),
             "2008-12-01",
             "2009-11-30",
             "2010-11-29",
+            "2023-11-27",
         )
 
     def test_immaculate_conception_day(self):
@@ -280,7 +284,7 @@ class TestPhilippines(CommonCountryTests, TestCase):
             "2022-05-03",
             "2023-04-21",
             "2024-04-10",
-            "2025-03-31",
+            "2025-04-01",
         )
         self.assertHolidayName(name, self.no_estimated_holidays, range(2002, 2050))
         self.assertNoHolidayName(name, self.no_estimated_holidays, range(1988, 2002))
@@ -447,7 +451,7 @@ class TestPhilippines(CommonCountryTests, TestCase):
             ("2023-10-30", "Elections special (non-working) day"),
             ("2023-11-01", "All Saints' Day"),
             ("2023-11-02", "Additional special (non-working) day"),
-            ("2023-11-30", "Bonifacio Day"),
+            ("2023-11-27", "Bonifacio Day"),
             ("2023-12-08", "Feast of the Immaculate Conception of Mary"),
             ("2023-12-25", "Christmas Day"),
             ("2023-12-26", "Additional special (non-working) day"),
@@ -460,7 +464,7 @@ class TestPhilippines(CommonCountryTests, TestCase):
             Philippines(years=2025),
             ("2025-01-01", "New Year's Day"),
             ("2025-01-29", "Chinese New Year"),
-            ("2025-03-31", "Eid'l Fitr"),
+            ("2025-04-01", "Eid'l Fitr"),
             ("2025-04-09", "Araw ng Kagitingan"),
             ("2025-04-17", "Maundy Thursday"),
             ("2025-04-18", "Good Friday"),
